package nce;

import java.net.MalformedURLException;
import java.net.URL;

import nce.editor.ColorManager;

import org.eclipse.core.runtime.Platform;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.gjt.sp.jedit.CatalogReader;
import org.gjt.sp.util.Log;
import org.osgi.framework.BundleContext;


/**
 * The activator class controls the plug-in life cycle
 */
public class ColoringEditorPlugin extends AbstractUIPlugin {

    public static final String STATUS_CATEGORY_MODE = "nce.editor.modeStatus";

    // The plug-in ID
	public static final String PLUGIN_ID = "nce.editor"; //$NON-NLS-1$

	// The shared instance
	private static ColoringEditorPlugin plugin;
	
    private ColorManager fColorManager;

	/**
	 * The constructor
	 */
	public ColoringEditorPlugin() {
	}

    public ColorManager getColorManager() {
        if (fColorManager == null) {
        	fColorManager = new ColorManager(getPreferenceStore());
        }
        return fColorManager;
    }

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
		
		Log.init(true, Log.ERROR);
		CatalogReader.loadCatalog();
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		if (fColorManager != null)
			fColorManager.dispose();
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static ColoringEditorPlugin getDefault() {
		return plugin;
	}

    public static Image getImage(String handle) {
        return getDefault().getImageRegistry().get(handle);
    }
	
    protected void initializeImageRegistry(ImageRegistry reg) {
        super.initializeImageRegistry(reg);
        reg.put("cube", getImageDescriptor("cube.png").createImage());
    }
    
	/**
	 * Returns an image descriptor for the image file at the given
	 * plug-in relative path
	 *
	 * @param path the path
	 * @return the image descriptor
	 */
    public static ImageDescriptor getImageDescriptor(String imageName) {
        String iconPath = "icons/";
        try {
            URL installURL = Platform.getBundle(PLUGIN_ID).getEntry("/");
            URL url = new URL(installURL, iconPath + imageName);
            return ImageDescriptor.createFromURL(url);
        } catch (MalformedURLException e) {
            // should not happen
            return ImageDescriptor.getMissingImageDescriptor();
        }
    }

    
}
