package nce.editor;

import org.eclipse.jface.text.BadLocationException;
import org.eclipse.jface.text.DocumentCommand;
import org.eclipse.jface.text.IDocument;
import org.eclipse.jface.text.IDocumentPartitioner;
import org.eclipse.jface.text.TextUtilities;
import org.eclipse.jface.text.source.IVerticalRuler;
import org.eclipse.jface.text.source.SourceViewer;
import org.eclipse.swt.widgets.Composite;
import org.gjt.sp.util.Log;
import org.gjt.sp.util.StandardUtilities;

public class ColoringEditorSourceViewer extends SourceViewer {

	public ColoringEditorSourceViewer(Composite parent, IVerticalRuler ruler, int styles) {
		super(parent, ruler, styles);
	}

	@Override
	protected void customizeDocumentCommand(DocumentCommand command) {

		JeditBuffer jEditBuffer = getJEditBuffer();
		if (jEditBuffer != null)
			customizeDocumentCommand(command, jEditBuffer);
		
		super.customizeDocumentCommand(command);

		Log.log(Log.DEBUG, this, 
				"customizeDocumentCommand: offset=" + command.offset + ", length=" + command.length + ", text=" + command.text);
	}

	private JeditBuffer getJEditBuffer() {
		IDocumentPartitioner partitioner = getDocument().getDocumentPartitioner();		
		if (partitioner instanceof ColoringEditorPartitioner) {
			ColoringEditorPartitionScanner jEditBuffer = ((ColoringEditorPartitioner)partitioner).getPartitionScanner();
			return jEditBuffer;
		}
		return null;
	}

	private void customizeDocumentCommand(DocumentCommand command, JeditBuffer jEditBuffer) {

			if (command.length == 0 && command.text != null 
					&& TextUtilities.endsWith(getDocument().getLegalLineDelimiters(), command.text) != -1)
				autoIndentAfterNewLine(getDocument(), command, jEditBuffer);

	}

	private void autoIndentAfterNewLine(IDocument document, DocumentCommand command, JeditBuffer jEditBuffer) {
		
		if (command.offset == -1 || document.getLength() == 0)
			return;

		try {
			
			int lineIndex = getDocument().getLineOfOffset(command.offset) + 1;
			int idealIndent = jEditBuffer.getIdealIndentForLine(lineIndex);

			StringBuffer buf= new StringBuffer(command.text);
			String indentString = StandardUtilities.createWhiteSpace(idealIndent, jEditBuffer.getTabSize());
			buf.append(indentString);

			command.text= buf.toString();

		} catch (BadLocationException excp) {
			// stop work
		}
	}

}
